[![Build Status](https://github.com/andgineer/bitwarden-import-msecure/workflows/CI/badge.svg)](https://github.com/andgineer/bitwarden-import-msecure/actions)
[![Coverage](https://raw.githubusercontent.com/andgineer/bitwarden-import-msecure/python-coverage-comment-action-data/badge.svg)](https://htmlpreview.github.io/?https://github.com/andgineer/bitwarden-import-msecure/blob/python-coverage-comment-action-data/htmlcov/index.html)
# bitwarden-import-msecure

Migration from mSecure to Bitwarden 

# Documentation

[Bitwarden Import mSecure](https://andgineer.github.io/bitwarden-import-msecure/)

# Developers

Do not forget to run `. ./activate.sh`.

# Scripts
    make help

## Coverage report
* [Codecov](https://app.codecov.io/gh/andgineer/bitwarden-import-msecure/tree/main/src%2Fbitwarden_import_msecure)
* [Coveralls](https://coveralls.io/github/andgineer/bitwarden-import-msecure)

> Created with cookiecutter using [template](https://github.com/andgineer/cookiecutter-python-package)